Getting Started
=====================

Functionality
-------------
The equinox platform may be useful to portfolio managers in financial industry or local government (portfolio managers, business analysts, data engineers and/or risk model developers). It currently targets the following use cases:

* CIRIS Emissions accounting and reporting
* PCAF Emissions accounting and reporting
* Standardized credit risk score according to EBA Specialized Lending criteria for Project Finance
* Equator Principles Reporting


.. note:: equinox is still in active development. The functionality of the platform will be significantly enhanced in future versions. If you have specific requests / ideas please raise them in our github repository.

